@@ -4,7 +4,7 @@ from django.db.models import Q
 
 from controller.models.utils import generate_chainer_manager
 from controller.utils import send_email_template
-from users.models import Group, Roles
+from users.models import Group, Roles, User
 
 from issues import settings
 
@@ -105,7 +105,10 @@ class Ticket(models.Model):
         return str(self.id)
     
     def get_notification_emails(self):
-        emails = settings.ISSUES_SUPPORT_EMAILS
+        emails = list(settings.ISSUES_SUPPORT_EMAILS)
+        if settings.ISSUES_NOTIFY_SUPERUSERS:
+            superusers = User.objects.filter(is_superuser=True)
+            emails += superusers.values_list('email', flat=True)
         emails.append(self.created_by.email)
         if self.owner:
             emails.append(self.owner.email)
